@@ -1,13 +1,13 @@
 from typing import Optional, Dict, Any, Sequence, TYPE_CHECKING, List
 
 from dataiku.langchain.base_rag_handler import BaseRagHandler, RetrievalSource
-from dataiku.langchain.content_part_types import MultipartContent, TextPart, ImageRetrieval, get_image_parts
+from dataiku.langchain.content_part_types import MultipartContent, TextPart
 from dataiku.langchain.metadata_generator import DKU_MULTIMODAL_CONTENT, DKU_DOCUMENT_INFO
-from dataiku.langchain.multimodal_content import MultimodalContent
+from dataiku.langchain.multimodal_content import from_doc
 from dataiku.llm.types import BaseVectorStoreQuerySettings, RetrievableKnowledge
 
 # Importing the classes that were moved out of this file for backwards compatibility with Answers plugin <=2.4.1
-from dataiku.langchain.content_part_types import ImageRefPart, ImageRetrieval, InlineImagePart # noqa: F401
+from dataiku.langchain.content_part_types import ImageRefPart, ImageRetrieval, InlineImagePart  # noqa: F401
 
 if TYPE_CHECKING:
     from langchain_core.documents import Document
@@ -15,7 +15,6 @@ if TYPE_CHECKING:
 AZURE_CAPTIONS_KEY = "captions"
 AZURE_ANSWERS_KEY = "answers"
 
-
 def _should_cleanup_for_azure(retrievable_knowledge: RetrievableKnowledge, query_settings: BaseVectorStoreQuerySettings) -> bool:
     if retrievable_knowledge.get("vectorStoreType", "") != "AZURE_AI_SEARCH":
         return False
@@ -25,7 +24,6 @@ def _should_cleanup_for_azure(retrievable_knowledge: RetrievableKnowledge, query
         return False
     return True
 
-
 class DocumentHandler(BaseRagHandler):
 
     def __init__(self,
@@ -68,10 +66,12 @@ class DocumentHandler(BaseRagHandler):
         Retrieve the document content based on the given retrieval source and return a list of multipart contents.
 
         For EMBEDDING retrieval sources, this method returns a list with a single text part.
-        For MULTIMODAL retrieval source, it uses the multimodal column type field to determine the parts to be returned
-        - If the type of the document is text, it returns a list with a single text part
-        - If the type of the document is images, it downloads images from the given folder and return a list of inline image parts if image_retrieval mode is IMAGE_INLINE,
-        or a list of image refs otherwise
+        For MULTIMODAL retrieval source, it uses the multimodal column type field to determine the parts to be returned.
+        - If the type of the document is text, it returns a list with a single text part.
+        - If the type of the document is images, return a list of image parts.
+        - If the type of the document is captioned_image, return a list of captioned image parts.
+
+        If image_retrieval is set to `IMAGE_INLINE`, images are downloaded from the given folder.
 
         For inconsistent metadata, it returns as a fallback a list with a single text part from the embedded data.
 
@@ -84,11 +84,8 @@ class DocumentHandler(BaseRagHandler):
             return [TextPart(index, self.get_content(doc))]
 
         # We are in the MULTIMODAL retrieval source case
-        multimodal_content = MultimodalContent.from_doc(doc, self.full_folder_id)
+        multimodal_content = from_doc(doc)
         if multimodal_content is None:
             return [TextPart(index, doc.page_content)]
 
-        if multimodal_content.type == MultimodalContent.Type.TEXT:
-            return [TextPart(index, multimodal_content.content)]
-
-        return get_image_parts(multimodal_content, index, image_retrieval, self.full_folder_id)
+        return multimodal_content.get_parts(index, image_retrieval, self.full_folder_id)
