@@ -320,9 +320,11 @@ app.controller("UploadCodeStudioTemplateController", function($scope, $state, $s
 });
 
 app.controller("CodeStudioTemplateController", function($scope, $rootScope, $controller, $stateParams, Assert, DataikuAPI, $state, TopNav, FutureProgressModal,
-                                                     ActivityIndicator, $q, Logs, CreateModalFromTemplate, WT1, Dialogs) {
+                                                     ActivityIndicator, $q, Logs, CreateModalFromTemplate, WT1, Dialogs, PermissionsDataFetcher) {
     $controller("CodeStudioTemplateCoreController", {$scope:$scope});
 
+    $scope.permissionsDataFetcher = PermissionsDataFetcher($scope);
+
     $scope.codeStudioTemplateResourcesEmptyCta = {
         title: "No file in this Code Studio template resources.",
         text: "Create your own files to use them in your blocks definition such as 'Append to Dockerfile' or 'Add Starter Files'.\nThese resources are versioned, so you should avoid big files.",
@@ -521,7 +523,8 @@ app.controller("CodeStudioTemplateController", function($scope, $rootScope, $con
         block.params.exposedPort = showExposedPort ? {label : "", exposeHtml : true, port : 8080, proxiedUrlSuffix : "/"} : null;
     };
 
-    const allZones = ['code_studio_versioned', 'code_studio_resources', 'project_lib_versioned', 'project_lib_resources', 'recipes', 'notebooks', 'user_versioned', 'user_resources'];
+    const allZones = ['code_studio_versioned', 'code_studio_resources', 'project_lib_versioned', 'project_lib_resources', 'recipes',
+        'notebooks', 'code_agents', 'agent_tools', 'user_versioned', 'user_resources', 'webapps'];
     $scope.buildNewSyncZone = function() {
         let existing = ((this.params||{}).syncedZones || []).map(z => z.zone);
         let available = allZones.filter(n => existing.indexOf(n) < 0);
@@ -863,7 +866,8 @@ app.directive('codeStudioTemplateSecurityPermissions', function(PermissionsServi
         restrict : 'A',
         templateUrl : '/templates/admin/code-studios/security-permissions.html',
         scope : {
-            codeStudioTemplate  : '='
+            codeStudioTemplate  : '=',
+            permissionsDataFetcher: '<'
         },
         link : function($scope, element, attrs) {
             $scope.ui = {};
