@@ -528,7 +528,18 @@
                     });
                 });
 
+                $scope.$watch('insight.params.def.filters', (nv, ov) => {
+                    if (_.isEqual(nv, ov)) {
+                        const loadingData = {
+                            successRoutine: () => {
+                            },
+                            errorRoutine: DashboardUtils.setError.bind([$scope]),
+                            unconfiguredRoutine: DashboardUtils.setLoaded.bind([$scope])
+                        };
 
+                        return computeAndExecutePivotRequest($scope.insight.params.def, loadingData, true);
+                    }
+                });
 
                 $scope.$watch('dashboardTheme', function(newDashboardTheme) {
                     if ($scope.tile.tileParams.useInsightTheme || !newDashboardTheme) {
