@@ -906,7 +906,7 @@ app.controller("MoveProjectModalController", function($scope, $rootScope, $contr
     };
 });
 
-app.service('ProjectActionsService', function($rootScope, $stateParams, CreateModalFromTemplate, DataikuAPI, FutureWatcher, $timeout, $state, WT1, Assert, ProgressStackMessageBuilder, AI_EXPLANATION_MODAL_MODES, ProjectFolderContext)  {
+app.service('ProjectActionsService', function($rootScope, $stateParams, CreateModalFromTemplate, DataikuAPI, FutureWatcher, $timeout, $state, WT1, Assert, ProgressStackMessageBuilder, AI_EXPLANATION_MODAL_MODES, ProjectFolderContext, FutureProgressModal)  {
     this.deleteThisProject = function(scope, projectSummary, projectKey = $stateParams.projectKey, transition = 'home', transitionParams = {}) {
         DataikuAPI.projects.checkDeletability(projectKey).success((data) => {
             if (data.anyMessage) {
@@ -923,20 +923,22 @@ app.service('ProjectActionsService', function($rootScope, $stateParams, CreateMo
                     newScope.projectSummary = projectSummary;
 
                     newScope.confirmProjectDeletion = function(clearManagedDatasets, clearOutputManagedFolders, clearJobAndScenarioLogs) {
-                        DataikuAPI.projects.delete(projectKey, clearManagedDatasets, clearOutputManagedFolders, clearJobAndScenarioLogs).success(function(deletionResult) {
-                            if(deletionResult.anyMessage) {
-                                CreateModalFromTemplate("/templates/projects/delete-project-results.html", scope, null, function(newScope) {
-                                    newScope.beforeDeletion = false;
-                                    newScope.results = deletionResult.messages;
-                                    newScope.$on('$destroy',function() {
-                                        $timeout(function() {
-                                            $state.transitionTo(transition, transitionParams);
+                        DataikuAPI.projects.delete(projectKey, clearManagedDatasets, clearOutputManagedFolders, clearJobAndScenarioLogs).success(function(future) {
+                            FutureProgressModal.show(scope, future, "Deleting project").then(function(deletionResult) {
+                                if(deletionResult.anyMessage) {
+                                    CreateModalFromTemplate("/templates/projects/delete-project-results.html", scope, null, function(newScope) {
+                                        newScope.beforeDeletion = false;
+                                        newScope.results = deletionResult.messages;
+                                        newScope.$on('$destroy',function() {
+                                            $timeout(function() {
+                                                $state.transitionTo(transition, transitionParams);
+                                            });
                                         });
                                     });
-                                });
-                            } else {
-                                $state.transitionTo(transition, transitionParams);
-                            }
+                                } else {
+                                    $state.transitionTo(transition, transitionParams);
+                                }
+                            });
 
                         }).error(setErrorInScope.bind($rootScope));
                         WT1.event("project-delete", {clearManagedDatasets, clearOutputManagedFolders, clearJobAndScenarioLogs});
