@@ -443,7 +443,6 @@ app.service("PluginCategoryService", function() {
 
 app.service("SelectablePluginsService", function($rootScope) {
     var svc = {
-
         listSelectablePlugins : function (inputTypesCount) {
 
             const pluginsById = $rootScope.appConfig.loadedPlugins.reduce( function (map, obj) {
@@ -472,36 +471,46 @@ app.service("SelectablePluginsService", function($rootScope) {
 
             const allTypes = {
                 "DATASET": {
-                    "selectableFromRole": 'selectableFromDataset',
+                    "selectableFromRole": ['selectableFromDataset'],
                     "inputName" : recipe.desc.selectableFromDataset,
                     "inputTypeCount": inputTypesCount.DATASET
                 },
                 "MANAGED_FOLDER":  {
-                    "selectableFromRole": 'selectableFromFolder',
+                    "selectableFromRole": ['selectableFromFolder'],
                     "inputName": recipe.desc.selectableFromFolder,
                     "inputTypeCount": inputTypesCount.MANAGED_FOLDER
                 },
                 "SAVED_MODEL": {
-                    "selectableFromRole": 'selectableFromSavedModel',
-                    "inputName": recipe.desc.selectableFromSavedModel,
+                    "selectableFromRole": ['selectableFromMLModel', 'selectableFromSavedModel'],
+                    "inputName": recipe.desc.selectableFromMLModel || recipe.desc.selectableFromSavedModel,
                     "inputTypeCount": inputTypesCount.SAVED_MODEL
+                },
+                "PROMPTABLE_MODEL": {
+                    "selectableFromRole": ['selectableFromPromptableModel', 'selectableFromSavedModel'],
+                    "inputName": recipe.desc.selectableFromPromptableModel || recipe.desc.selectableFromSavedModel,
+                    "inputTypeCount": inputTypesCount.PROMPTABLE_MODEL
                 }
             };
             for (let [inputType, nb_input] of Object.entries(inputTypesCount)) {
                 const typeParams = allTypes[inputType];
+                if (!typeParams) {
+                    return { ok: false, reason: "Unsupported type " + inputType };
+                }
+
                 var role = recipe.desc.inputRoles.find( (el) => { return el.name == typeParams.inputName; });
                 // role does not exist
                 if (!role)
                     return { ok: false, reason: "InputRole selectable from " + inputType + " doesn't exist in this recipe."};
 
                 // recipe does not accept selectable inputs of this type
-                if (!recipe.desc.hasOwnProperty(typeParams.selectableFromRole)) {
+                if (!typeParams.selectableFromRole.some(prop => prop in recipe.desc)) {
                     return { ok: false, reason: "Input role type " + inputType + " of (" + role.name + ") is not selectable for this recipe."};
                 }
                 // recipe does not accept inputs of type of the role
                 if ((inputType === "DATASET" && !role.acceptsDataset) ||
                     (inputType === "MANAGED_FOLDER" && !role.acceptsManagedFolder) ||
-                    (inputType === "SAVED_MODEL" && !role.acceptsSavedModel)) {
+                    (inputType === "SAVED_MODEL" && !(role.acceptsSavedModel || role.acceptsMLModel)) ||
+                    (inputType === "PROMPTABLE_MODEL" && !(role.acceptsSavedModel || role.acceptsPromptableModel))) {
                     return { ok: false, reason: "Recipe doesn't accept " + inputType + " as input for the selectable role (" + role.name + ")."};
                 }
 
@@ -619,7 +628,21 @@ app.service("RecipeComputablesService", function(Assert, DataikuAPI, $stateParam
                 }
             });
             return usable;
-        }
+        },
+
+        acceptsEvaluationStore: function(role) {
+            return role.acceptsModelEvaluationStore || role.acceptsAgentEvaluationStore || role.acceptsLLMEvaluationStore;
+        },
+
+        setMesFlavor: function($scope, role) {
+            if (role.acceptsModelEvaluationStore) {
+                $scope.mesFlavor = "TABULAR";
+            } else if (role.acceptsAgentEvaluationStore) {
+                $scope.mesFlavor = "AGENT";
+            } else if (role.acceptsLLMEvaluationStore) {
+                $scope.mesFlavor = "LLM";
+            }
+        },
     };
     return svc;
 });
