@@ -27,7 +27,8 @@
                     $scope.recipe.params.defaultVlmId = $scope.availableVLMs[0].id;
                 }
             }
-        }
+        };
+                   
 
         $scope.EMBED_DOCS_EXTRACTION_MODES = [ // keep in sync with EmbedDocumentsRecipeParams.java - ExtractionMode enum
             {
@@ -68,44 +69,56 @@
             },
         };
 
-        $scope.VLM_EXTRACTION_PROMPTS = {
-            'SUMMARY_PROMPT': "Generate a concise summary, up to __DKU_NUMBER_OF_CHARS__ characters derived from the screenshot(s) of document page(s) provided. \n"
-                + "Begin with a brief overview and highlight crucial words, facts, or concepts to enhance both semantic and keyword searchability.\n"
-                + "Omit any references to the original source.\n",
+        DataikuAPI.flow.recipes.nlp.getDefaultDocExtractionPrompts($stateParams.projectKey, $scope.recipe.name).success(function(data) {
+            $scope.promptsTemplates = data; 
+        }).error(setErrorInScope.bind($scope));
 
-            'FULL_CONTENT_PROMPT': "Extract the information from the screenshot(s) of document page(s) provided at the end, maintaining the original text without alteration. Follow these guidelines:\n"
-                + "* Use Markdown to format the text, including headers such as Title, Subtitle, and Main Sections, as well as any tables present in the document.\n"
-                + "* Describe any images and charts within the document screenshot(s), as the visual content cannot be directly extracted.\n"
-                + "* Exclude any hyperlinks, as they cannot be extracted from an image.\n"
-                + "* Ensure the text content remains unchanged.\n"
-                + "* Extract all text, including any footers or reference lists.\n",
-        }
+        $scope.getPrompt = function(charsLimit, promptVersion) {
+            var promptTemplate;
+            if (!$scope.promptsTemplates){
+                return ""; // if not yet retrieved
+            }
+            switch (promptVersion) {
+            case "DEFAULT_VLM_EXTRACTION":
+                promptTemplate = $scope.promptsTemplates.defaultVlmExtractionTemplate;
+                break;
+            case "SUMMARY_PROMPT":
+                promptTemplate = $scope.promptsTemplates.vlmSummaryExtractionTemplate;
+                break;
+            case "FULL_CONTENT_PROMPT":
+                promptTemplate = $scope.promptsTemplates.vlmFullExtractionTemplate;
+                break;
+            case "ANNOTATION_PROMPT":
+                promptTemplate = $scope.promptsTemplates.vlmAnnotationTemplate;
+                break;
+            default:
+                return ""; // Unsupported
+            }
+            return promptTemplate.replace($scope.promptsTemplates.limitPlaceholder, charsLimit);
+        };
 
-        $scope.IMAGE_CAPTION_VLM_PROMPT = "You are analyzing a document image to extract structured information for downstream processing and retrieval (RAG). Your goal is to extract all meaningful, reusable content in a markdown format up to __DKU_NUMBER_OF_CHARS__ characters.\n"
-            + "Instructions:\n"
-            + "1. Classify the image type: diagram, chart, table, handwriting, printed text, or mixed.\n"
-            + "2. Extract and describe based on type:\n"
-            + "- Diagram or Chart: Provide a detailed description of the structure, relationships, labels, axes, values, legends, and overall meaning. Convert all meaningful content into text. Summarize insights if relevant.\n"
-            + "- Handwritten or Printed Text: Transcribe all visible text accurately. Preserve formatting and structure. Use markdown headings, bullets, or code blocks as appropriate.\n"
-            + "- Tables: Reconstruct the table as markdown. Ensure all rows and columns are preserved. Retain headings and numerical precision.\n"
-            + "- Mixed Content: Separate and extract each part individually (e.g., transcribe text, describe chart, and format table).\n"
-            + "3. Preserve structure and context: Use markdown to reflect hierarchy, formatting, and clarity.\n"
-            + "4. Avoid assumptions or hallucinations. If any part is unclear, describe it as such.\n"
-            + "5. Ensure each section is a reusable, standalone chunk.\n"
-            + "If the image is a logo, signature, or QR code, don't describe it and return an empty string.\n";
+        $scope.getPromptFromRule = function (rule, promptVersion) {
+            if (promptVersion) {
+                var chunkSize = $scope.defaultChunkSize;
+                if (rule?.splittingSettings?.chunkSizeCharacters) { // splitting settings can be null for extract content recipe
+                    chunkSize = rule.splittingSettings.chunkSizeCharacters;
+                }
+                return $scope.getPrompt(chunkSize, promptVersion);
+            }
+        };
 
-        $scope.getPrompt = function(chunkSizeCharacters, promptVersion) {
-            return $scope.VLM_EXTRACTION_PROMPTS[promptVersion].replace("__DKU_NUMBER_OF_CHARS__", chunkSizeCharacters);
-        }
+        $scope.overrideVLMAnnotationCustomPromptWith = function (rule) {
+            rule.structuredSettings.customVLMPrompt = $scope.getPromptFromRule(rule, "ANNOTATION_PROMPT");
+        };
 
-        $scope.getVLMAnnotationPrompt = function(chunkSizeCharacters) {
-            return $scope.IMAGE_CAPTION_VLM_PROMPT.replace("__DKU_NUMBER_OF_CHARS__", chunkSizeCharacters);
-        }
+        $scope.overrideVLMExtractionCustomPromptWith = function (rule, promptVersion) {
+            rule.vlmSettings.customPrompt = $scope.getPromptFromRule(rule, promptVersion);
+        };
 
         $scope.getActiveVLMfromLLMid = function(vlmId) {
             return $scope.availableVLMs.find(llm => llm.id === vlmId);
 
-        }
+        };
 
         $scope.recipe.params.rules = $scope.recipe.params.rules || [];  // shouldn't be needed as default rules are retrieved from the backend
 
@@ -123,9 +136,9 @@
                 "customNbPages": 1,
                 "customPagesOverlap": 0,
                 "useCustomPrompt" : false,
-                "customPrompt": $scope.getPrompt(chunkSize, "SUMMARY_PROMPT"),
+                "customPrompt": $scope.getPrompt(chunkSize, 'DEFAULT_VLM_EXTRACTION'),
             }
-        }
+        };
 
         $scope.makeDefaultStructuredSettings = function() {
             let chunkSize = $scope.defaultChunkSize;
@@ -136,10 +149,10 @@
                 "ocrEngine": "AUTO",
                 "ocrLanguages": "en",
                 "useCustomVLMPrompt" : false,
-                "customVLMPrompt": $scope.getVLMAnnotationPrompt(chunkSize),
+                "customVLMPrompt": $scope.getPrompt(chunkSize, "ANNOTATION_PROMPT"),
                 "enableImageClassificationFiltering": true,
             };
-        }
+        };
 
         $scope.addNewRule = function() {
             $scope.recipe.params.rules.push({
@@ -163,7 +176,7 @@
                 "storeInMultimodalColumn": "FULL_CONTENT"
             });
             $scope.uiState.showAdvancedSettings.push(false);
-        }
+        };
 
         $scope.onRuleActionChange = function(idx) {
             let ruleToBeUpdated = idx == -1 ? $scope.recipe.params.allOtherRule : $scope.recipe.params.rules[idx];
@@ -175,19 +188,20 @@
                 ruleToBeUpdated.structuredSettings = ruleToBeUpdated.structuredSettings || $scope.makeDefaultStructuredSettings();
                 ruleToBeUpdated.storeInMultimodalColumn = $scope.shouldStoreDetectedImages(ruleToBeUpdated) ? "IMAGES" : "FULL_CONTENT";
             }
-        }
+        };
+
         $scope.clearAll = function() { // remove all rules except 'all other files' rule
             // eslint-disable-next-line for-direction
             for (var i = $scope.recipe.params.rules.length - 1; i >= 0; i--) {
                 $scope.removeRule(i);
             }
-        }
+        };
 
         $scope.removeRule = function(idx) {
             // only 'classic' (not 'allOtherFiles') rules can be deleted
             $scope.recipe.params.rules.splice(idx, 1);
             $scope.uiState.showAdvancedSettings.splice(idx, 1);
-        }
+        };
 
         $scope.uiState = {
             currentStep: 'strategy',
@@ -294,12 +308,12 @@
 
         $scope.getRulesSchema = function() {
             return $scope.ruleSchema;
-        }
+        };
 
         $scope.createCustomRulesFrom = function(extractionMode) {
             if ($scope.recipe.params) {
                 const llmId = $scope.retrievableKnowledge ? $scope.retrievableKnowledge.embeddingLLMId: null;
-                    DataikuAPI.flow.recipes.nlp.getDefaultEmbedDocumentRules(extractionMode.id, llmId, $scope.recipe.params.defaultVlmId, $stateParams.projectKey, $scope.recipe.params.defaultImageHandlingMode).success(function(data) {
+                    DataikuAPI.flow.recipes.nlp.getDefaultDocExtractionRules(extractionMode.id, llmId, $scope.recipe.params.defaultVlmId, $stateParams.projectKey, $scope.recipe.params.defaultImageHandlingMode, $scope.recipe.name).success(function(data) {
                     if (data) {
                         $scope.recipe.params.rules = data.rules;
                         Object.assign($scope.recipe.params.allOtherRule, data.allOtherRule); // only copy properties without changing reference
@@ -307,17 +321,18 @@
                     }
                 }).error(setErrorInScope.bind($scope));
             }
+
         }
 
         $scope.overrideCustomPromptWith = function (rule, promptVersion) {
             if (promptVersion && $scope.VLM_EXTRACTION_PROMPTS[promptVersion]) {
-                let chunkSize = $scope.defaultChunkSize
+                let chunkSize = $scope.defaultChunkSize;
                 if (rule?.splittingSettings?.chunkSizeCharacters) { // splitting settings can be null for extract content recipe
                     chunkSize = rule.splittingSettings.chunkSizeCharacters;
                 }
                 rule.vlmSettings.customPrompt = $scope.getPrompt(chunkSize, promptVersion);
             }
-        }
+        };
 
         $scope.overrideVLMAnnotationCustomPromptWith = function (rule) {
             rule.structuredSettings.customVLMPrompt = $scope.getVLMAnnotationPrompt(rule.splittingSettings.chunkSizeCharacters);
@@ -328,7 +343,7 @@
                 return "/static/dataiku/images/recipes/"+ $scope.recipe.type+ "/"+ $scope.recipe.params.extractionMode + "_WITH_IMAGE_HANDLING.svg"
             }
             return "/static/dataiku/images/recipes/"+ $scope.recipe.type+ "/"+ $scope.recipe.params.extractionMode + ".svg"
-        }
+        };
 
 
         $scope.shouldStoreDetectedImages = function(rule){
