@@ -2,8 +2,9 @@
 'use strict';
 const app = angular.module('dataiku.retrieval-augmented-llm', ['dataiku.ml.report', 'dataiku.lambda']);
 
-app.controller("_RetrievalAugmentedLLMSavedModelController", function($scope, $rootScope, $state, $controller, $stateParams, $q, DataikuAPI, Dialogs, DKUtils, ActiveProjectKey, FullModelLikeIdUtils, SmartId) {
+app.controller("RetrievalAugmentedLLMSavedModelController", function($scope, $rootScope, $state, $controller, $stateParams, $q, DataikuAPI, Dialogs, DKUtils, ActiveProjectKey, FullModelLikeIdUtils, SmartId, Debounce) {
     $controller("_SavedModelReportController", {$scope});
+    $scope.uiState = $scope.uiState || {};
 
     DataikuAPI.savedmodels.llmCommon.getStatus(ActiveProjectKey.get(), $stateParams.smId).success(function(data){
         $scope.fillVersionSelectorStuff(data);
@@ -29,8 +30,7 @@ app.controller("_RetrievalAugmentedLLMSavedModelController", function($scope, $r
         }
         $scope.currentlySavedInlineModel = angular.copy(nv.inlineVersions[$scope.currentVersionIdx]);
         $scope.currentVersionData = nv.inlineVersions[$scope.currentVersionIdx];
-
-        $scope.ragllmSettings = $scope.currentVersionData.ragllmSettings;
+        $scope.uiState.ragllmSettings = $scope.currentVersionData.ragllmSettings;
 
         $scope.getMetadataColumns = function() {
             const schema = $scope.retrievableKnowledge?.metadataColumnsSchema ?? [];
@@ -40,22 +40,26 @@ app.controller("_RetrievalAugmentedLLMSavedModelController", function($scope, $r
                 .filter(col => col !== multimodalColumn);
         };
 
-        DataikuAPI.retrievableknowledge.getFullInfo(ActiveProjectKey.get(), SmartId.create($scope.ragllmSettings.kbRef, $stateParams.projectKey)).then(function({ data }) {
+        DataikuAPI.retrievableknowledge.getFullInfo(ActiveProjectKey.get(), SmartId.create($scope.uiState.ragllmSettings.kbRef, $stateParams.projectKey)).then(function({ data }) {
             $scope.rkFullInfo = data;
             $scope.retrievableKnowledge = data.retrievableKnowledge;
             if (data.retrievableKnowledge.vectorStoreType === 'VERTEX_AI_GCS_BASED') {
-                $scope.ragllmSettings.enforceDocumentLevelSecurity = false;
+                $scope.uiState.ragllmSettings.enforceDocumentLevelSecurity = false;
             }
             $scope.metadataColumns = $scope.getMetadataColumns();
         }).catch(setErrorInScope.bind($scope));
 
-        DataikuAPI.retrievableknowledge.getCurrentVersionInfo($stateParams.projectKey, $scope.ragllmSettings.kbRef)
+        DataikuAPI.retrievableknowledge.getCurrentVersionInfo($stateParams.projectKey, $scope.uiState.ragllmSettings.kbRef)
             .then(function({ data }) {
                 $scope.embeddingRecipeDesc = data.embeddingRecipeParams;
                 $scope.isRkBuilt = data.isBuilt;
             }).catch(setErrorInScope.bind($scope));
     });
 
+    // to trigger change detection in child components
+    $scope.currentVersionUpdateCounter = 0;
+    $scope.$watch('currentVersionData', Debounce().withDelay(200, 200).wrap(() => $scope.currentVersionUpdateCounter++), true);
+
     $scope.save = function() {
         if (!$scope.isDirty()) {
             return $q.when('retrieval-augmented LLM not dirty');
@@ -105,7 +109,7 @@ app.controller("_RetrievalAugmentedLLMSavedModelController", function($scope, $r
 
     $scope.isConfigDirty = function() {
         let frankenVersion = angular.copy($scope.currentlySavedInlineModel);
-        frankenVersion["quickTestQuery"] = $scope.savedModel.inlineVersions[$scope.currentVersionIdx]["quickTestQuery"];
+        frankenVersion["quickTestQueryStr"] = $scope.savedModel.inlineVersions[$scope.currentVersionIdx]["quickTestQueryStr"];
 
         return !angular.equals(frankenVersion, $scope.savedModel.inlineVersions[$scope.currentVersionIdx]);
     };
@@ -116,12 +120,16 @@ app.controller("_RetrievalAugmentedLLMSavedModelController", function($scope, $r
     };
     $rootScope.retrievalAugmentedModelIsDirty = $scope.isDirty;
 
-    checkChangesBeforeLeaving($scope, $scope.isDirty);
+    function allowedTransitionsFn(data) {
+        return data.toState?.name?.startsWith('projects.project.savedmodels.savedmodel.retrievalaugmentedllm') 
+            && data.fromState?.name?.startsWith('projects.project.savedmodels.savedmodel.retrievalaugmentedllm') 
+            && data.toParams?.fullModelId === data.fromParams?.fullModelId;
+    }
+
+    checkChangesBeforeLeaving($scope, $scope.isDirty, null, allowedTransitionsFn);
 });
 
-app.controller("RetrievalAugmentedLLMSavedModelDesignController", function($scope, $rootScope, $state, $stateParams, $controller, ActivityIndicator, DataikuAPI, PluginConfigUtils, PluginsService, TopNav, CreateModalFromTemplate) {
-    $controller("_RetrievalAugmentedLLMSavedModelController", {$scope});
-
+app.controller("RetrievalAugmentedLLMSavedModelDesignController", function($scope, $rootScope, $state, $stateParams, $controller, ActivityIndicator, DataikuAPI, PluginConfigUtils, PluginsService, TopNav) {
     // Keep in sync with RAGLLMSettings.DEFAULT_CONTEXT_MESSAGE
     $scope.defaultPrompt = "Use the following pieces of context to answer the question at the end.\n"
                            + "If you do not know the answer, just say that you do not know, do not try to make up an answer.";
@@ -139,15 +147,15 @@ app.controller("RetrievalAugmentedLLMSavedModelDesignController", function($scop
         }
     });
 
-    $scope.openTestInPromptStudioModal = function () {
-        CreateModalFromTemplate('/templates/savedmodels/retrieval-augmented-llm/test-in-prompt-studio.html', $scope, 'TestInPromptStudioModalController');
-    };
-
     $scope.hasMetadataColumns = function() {
         const schema = $scope.retrievableKnowledge?.metadataColumnsSchema ?? [];
         return schema.length > 0;
     };
 
+    $scope.hasLoadedContext = function() {
+        return $scope.uiState.ragllmSettings && $scope.metadataColumns && $scope.availableAugmentableLLMs;
+    }
+
     $scope.disableTextGuardrails = function (ragllmSettings) {
         ragllmSettings.ragSpecificGuardrails.faithfulnessSettings.enabled = false;
         ragllmSettings.ragSpecificGuardrails.relevancySettings.enabled = false;
@@ -164,7 +172,6 @@ app.controller("RetrievalAugmentedLLMSavedModelDesignController", function($scop
 });
 
 app.controller("RetrievalAugmentedLLMSavedModelSettingsController", function($scope, $state, $controller, DataikuAPI, TopNav) {
-    $controller("_RetrievalAugmentedLLMSavedModelController", { $scope });
 
     $scope.$watch("savedModel", (nv) => {
         if (!nv) return;
@@ -196,45 +203,56 @@ app.controller("RetrievalAugmentedLLMSavedModelSettingsController", function($sc
     }
 });
 
+app.controller("RetrievalAugmentedLLMSavedModelLogsController", function($scope, $stateParams, $controller, DataikuAPI, Dialogs, TopNav) {
+
+    $scope.listLogs = function() {
+        DataikuAPI.savedmodels.retrievalAugmentedLLMs.listLogs($stateParams.projectKey, $scope.savedModel.id, $scope.currentVersionId).success(function(data) {
+            $scope.rallmLogs = data;
+        }).error(setErrorInScope.bind($scope));
+    }
+
+    $scope.clearLogs = function() {
+        const title = 'Confirm logs deletion';
+        const message = 'Are you sure you want to clear the logs for this retrieval-augmented LLM?';
+
+        Dialogs.confirm($scope, title, message).then(() => {
+            DataikuAPI.savedmodels.retrievalAugmentedLLMs.clearLogs($stateParams.projectKey, $scope.savedModel.id, $scope.currentVersionId)
+                .error(setErrorInScope.bind($scope))
+                .finally($scope.listLogs);
+        });
+    }
+
+    $scope.deleteLog = function(projectKey, savedModelId, versionId, logName) {
+        return DataikuAPI.savedmodels.retrievalAugmentedLLMs.deleteLog(projectKey, savedModelId, versionId, logName)
+            .error(setErrorInScope.bind($scope))
+            .finally($scope.listLogs);
+    }
+
+    $scope.getLog = DataikuAPI.savedmodels.retrievalAugmentedLLMs.getLog;
+
+    $scope.logDownloadURL = (projectKey, savedModelId, versionId, logName) => {
+        const params = new URLSearchParams({
+            projectKey,
+            smId: savedModelId,
+            versionId,
+            logName
+        });
+        return `/dip/api/savedmodels/retrieval-augmented-llm/stream-log?${params}`;
+    };
+
+    $scope.$watch("savedModel", (nv) => {
+        if (!nv) return;
+
+        $scope.listLogs();
+
+        if (!$scope.noSetLoc) {
+            TopNav.setLocation(TopNav.TOP_GENAI_MODELS, TopNav.LEFT_GENAI_MODELS, "RETRIEVAL-AUGMENTED_LLM-SAVED_MODEL-VERSION", "logs");
+        }
+    });
+});
+
 app.controller("RetrievalAugmentedLLMSavedModelHistoryController", function($scope, $controller, TopNav) {
-    $controller("_RetrievalAugmentedLLMSavedModelController", { $scope });
     TopNav.setLocation(TopNav.TOP_GENAI_MODELS, TopNav.LEFT_GENAI_MODELS, "RETRIEVAL-AUGMENTED_LLM-SAVED_MODEL-VERSION", "history");
 });
 
-/* ***************************** Test In Prompt Studio Modal ************************** */
-
-app.controller('TestInPromptStudioModalController', function ($scope, $stateParams, $state, DataikuAPI) {
-    $scope.prompt = {};
-
-    DataikuAPI.promptStudios
-        .listHeads($stateParams.projectKey)
-        .then(function ({ data }) {
-            const createOption = { createOption: true, name: 'Create a new Prompt studio...' };
-            $scope.promptStudios = data;
-            $scope.promptStudios.unshift(createOption);
-            $scope.prompt.studio = createOption;
-            $scope.prompt.newPromptName = '';
-            return;
-        })
-        .catch(setErrorInScope.bind($scope));
-
-    $scope.editInStudio = function () {
-        const promptCreationSettings = {};
-        if ($scope.prompt.studio.createOption) {
-            promptCreationSettings.newPromptStudioName = $scope.prompt.newPromptName;
-        } else {
-            promptCreationSettings.promptStudioId = $scope.prompt.studio.id;
-        }
-
-        $scope.saveRetrievalAugmentedModel(true).then(function () {
-            DataikuAPI.promptStudios
-                .testFromKb($stateParams.projectKey, $scope.savedModel.id, promptCreationSettings)
-                .then(function ({ data }) {
-                    $state.go('projects.project.promptstudios.promptstudio', { promptStudioId: data.promptStudioId, promptId: data.promptStudioPromptId });
-                })
-                .catch(setErrorInScope.bind($scope));
-        });
-    };
-});
-
 })();
