@@ -5,11 +5,15 @@
         .factory('BinnedXYChart', BinnedXYChart);
 
     // (!) This service previously was in static/dataiku/js/simple_report/scatter/aggr_scatter.js
-    function BinnedXYChart(ChartManager, ChartDataWrapperFactory, BinnedXYUtils, d3Utils, D3ChartAxes, ChartDataUtils, ChartAxesUtils, SVGUtils, ChartYAxisPosition) {
+    function BinnedXYChart(ChartManager, ChartDataWrapperFactory, BinnedXYUtils, d3Utils, D3ChartAxes, ChartDataUtils, ChartAxesUtils, SVGUtils, ChartYAxisPosition, ChartHierarchyDimension, ChartDimension, ChartDrilldown) {
         return function($container, chartDef, chartHandler, axesDef, data) {
+
+            const xDimension = ChartDimension.getXDimension(chartDef);
+            const yDimension = ChartDimension.getYDimension(chartDef);
+
             const chartData = ChartDataWrapperFactory.chartTensorDataWrapper(data, axesDef),
                 facetLabels = chartData.getAxisLabels('facet') || [null],
-                pointsData = BinnedXYUtils.prepareData(chartDef, chartData),
+                pointsData = BinnedXYUtils.prepareData(chartData),
                 yAxisID = ChartAxesUtils.computeYAxisID(ChartYAxisPosition.LEFT),
                 yCustomExtent = ChartAxesUtils.getYAxisCustomExtent(chartDef.yAxesFormatting, yAxisID);
 
@@ -55,8 +59,8 @@
 
             ChartManager.initChart(chartDef, chartHandler, chartData, $container, drawFrame,
                 {
-                    x: { type: 'DIMENSION', mode: 'POINTS', padding: 1, dimension: chartDef.xDimension[0], name: 'x', customExtent: chartDef.xAxisFormatting.customExtent },
-                    [yAxisID]: { id: yAxisID, type: 'DIMENSION', mode: 'POINTS', padding: 1, dimension: chartDef.yDimension[0], name: 'y', customExtent: yCustomExtent, position: ChartYAxisPosition.LEFT }
+                    x: { type: 'DIMENSION', mode: 'POINTS', padding: 1, dimension: xDimension, name: 'x', customExtent: chartDef.xAxisFormatting.customExtent },
+                    [yAxisID]: { id: yAxisID, type: 'DIMENSION', mode: 'POINTS', padding: 1, dimension: yDimension, name: 'y', customExtent: yCustomExtent, position: ChartYAxisPosition.LEFT }
                 },
                 { type: 'MEASURE', measureIdx: colorMeasure });
 
@@ -75,6 +79,16 @@
                 return Math.min(yFraction, xFraction);
             }
 
+            function addBackgroundContextualMenuHandler(g, chartBase) {
+                const xHierarchyLevel = ChartHierarchyDimension.getCurrentHierarchyLevel(chartDef, 'x');
+                const yHierarchyLevel = ChartHierarchyDimension.getCurrentHierarchyLevel(chartDef, 'y');
+                if (xHierarchyLevel > 0 || yHierarchyLevel > 0) {
+                    const anchor = SVGUtils.addPlotAreaContextMenuAnchor(g, chartBase.vizWidth, chartBase.vizHeight);
+                    chartBase.contextualMenu.addChartContextualMenuHandler(anchor.node(), undefined,
+                        () => ChartDrilldown.getDrillupActions(chartDef));
+                }
+            }
+
             /**
              * Get the size of one step within the axis range.
              * Useful for computing the size of elements in chart (e.g bubbles or rectangles)
@@ -110,7 +124,6 @@
             }
 
             function BinnedXYChartDrawer(g, chartDef, chartHandler, chartData, chartBase, pointsData, f) {
-
                 const xStep = getRangeStep('x', chartBase.xAxis, chartData);
                 const yStep = getRangeStep('y', chartBase.yAxes[0], chartData);
                 const radius = Math.min(xStep / 3.5, yStep / 3.5);
@@ -147,7 +160,7 @@
                         chartBase.contextualMenu.addContextualMenuHandler(this, angular.extend({}, d, { facet: f }));
                     });
 
-                points.transition()
+                points.interrupt('updateCircles').transition('updateCircles')
                     .attr('r', function(d) {
                         if (chartData.getCount(d) > 0) {
                             if (sizeScale) {
@@ -164,10 +177,10 @@
 
                 // Clip paths to prevent points from overlapping axis when user chose a custom range which results in the bar being cropped (out of visible range)
                 ChartAxesUtils.isCroppedChart(chartDef) && SVGUtils.clipPaths(chartBase, g, wrapper);
+                addBackgroundContextualMenuHandler(g, chartBase);
             }
 
             function RectBinnedXYChartDrawer(g, chartDef, chartHandler, chartData, chartBase, pointsData, f) {
-
                 const xStep = getRangeStep('x', chartBase.xAxis, chartData);
                 const yStep = getRangeStep('y', chartBase.yAxes[0], chartData);
                 let widthScale, heightScale;
@@ -218,7 +231,7 @@
                         chartBase.contextualMenu.addContextualMenuHandler(this, angular.extend({}, d, { facet: f }));
                     });
 
-                points.transition()
+                points.interrupt('updateRectangles').transition('updateRectangles')
                     .attr('x', function(d) {
                         const x = getPosition('x', chartBase.xAxis, chartData, d.x);
                         return x - rectWidth(d) / 2;
@@ -233,6 +246,7 @@
 
                 // Clip paths to prevent points from overlapping axis when user chose a custom range which results in the bar being cropped (out of visible range)
                 ChartAxesUtils.isCroppedChart(chartDef) && SVGUtils.clipPaths(chartBase, g, points);
+                addBackgroundContextualMenuHandler(g, chartBase);
             }
 
             function HexBinnedXYChartDrawer(g, chartDef, chartHandler, chartData, chartBase, pointsData, f) {
@@ -321,7 +335,7 @@
                     });
                 hexagons.exit().remove();
 
-                hexagons.transition().call(formatHexagons);
+                hexagons.interrupt('updateHexagons').transition('updateHexagons').call(formatHexagons);
             }
         };
     }
