@@ -446,7 +446,10 @@
                             dimension.value,
                             formattingOptions
                         );
-                        filterValue = dimension.label;
+                        filterValue = ChartLabels.getFormattedLabel(
+                            { label: dimension.label },
+                            dimension.isA === 'measure' ? formattingOptions : {}
+                        );
                         axisElt = dimension;
                         dimension = radarDimension;
                     } else {
@@ -469,12 +472,12 @@
                     const isTotalBar = axisElt.label === DKU_TOTAL_VALUE;
                     const canAddEmptyFilter = canChartTypeBeFiltered && !isRadarChartMeasure && !isInReusableDimensionPreview;
                     const canFilter = canChartTypeBeFiltered && !isRadarChartMeasure && !isOthersBin && !isTotalBar && (!isInDashboard || DashboardFilters.canCrossFilter($stateParams.pageId)) && !isInReusableDimensionPreview;
-                    const isDrillable = canFilter && !isInDashboard && ChartDimension.isDrillable(dimension);
+                    const isDrillable = canFilter && !isInDashboard && ChartDimension.isDrillableForElement(chartDef, dimension, axisElt);
                     const nativeDrilldownType = isDrillable ? ChartDimension.isGroupedNumerical(dimension) ? 'NUMERICAL' : 'DATE' : null;
-                    const isHierarchyDrillable = dimension && !isTotalBar && ChartFeatures.canDrillHierarchy(chartDef.type) && dimension.hierarchyId && !isOthersBin;
+                    const isHierarchyDrillable = dimension && !isTotalBar && ChartFeatures.canDrillHierarchy(chartDef.type) && dimension.hierarchyId && !isOthersBin && !isRadarChartMeasure;
                     const isHierarchyDrillableDown = isHierarchyDrillable && ChartHierarchyDimension.canDimensionDrillDown(chartDef, dimension);
                     const isHierarchyDrillableUp = isHierarchyDrillable && ChartHierarchyDimension.canDimensionDrillUp(chartDef, dimension);
-                    const hierarchyName = ChartHierarchyDimension.getDimensionHierarchyName(chartDef, dimension);
+                    const hierarchyName = !isRadarChartMeasure && ChartHierarchyDimension.getDimensionHierarchyName(chartDef, dimension);
                     const previousHierarchyDimension = ChartHierarchyDimension.getDimensionHierarchyPreviousDimensionName(chartDef, dimension);
                     const nextHierarchyDimension = ChartHierarchyDimension.getDimensionHierarchyNextDimensionName(chartDef, dimension);
                     const tooltipLabel = `${ChartLabels.getDimensionLabel(dimension)} - ${filterValue}`;
@@ -488,6 +491,7 @@
                         drillUpActionId: `${dimensionTooltipId}-drill-up`,
                         colored,
                         tooltipLabel,
+                        filterValue,
                         isDrillable,
                         nativeDrilldownType,
                         isHierarchyDrillableDown,
@@ -506,7 +510,11 @@
                             chartDef.filters = ChartFilters.updateOrAddFilter(chartDef.filters, newFilter);
                         },
                         drill: () => {
-                            ChartDrilldown.handleNativeDrillDown(chartDef, axisElt, dimension);
+                            const { updatedFilters, newDateRange } = ChartDrilldown.getUpdateForNativeDrillDown(chartDef, axisElt, dimension);
+                            if (newDateRange) {
+                                dimension.dateParams.mode = newDateRange;
+                            }
+                            chartDef.filters = updatedFilters;
                         },
                         hierarchyDrillDown: () => {
                             ChartDrilldown.handleDrillDown(chartDef, dimension, DRILL_DOWN_SOURCE.TOOLTIP, axisElt);
