@@ -126,6 +126,29 @@ app.service("TaggableObjectsUtils", function($state, $stateParams) {
         return commonType || 'TAGGABLE_OBJECT';
     };
 
+    this.getCommonIndexableType = function(items, typeFieldAccessor) {
+        const types = new Set(items.map(item => typeFieldAccessor?.(item) ?? item));
+        return types.size === 1 ? types.values().next().value : 'INDEXABLE_OBJECT';
+    };
+
+    this.getIndexableTypeFromNode = function(node, nodeType) {
+        const taggableType = this.fromNodeType(nodeType);
+        if (taggableType === 'SAVED_MODEL' && node.savedModelType) {
+            switch (node.savedModelType) {
+                case 'PYTHON_AGENT':
+                case 'PLUGIN_AGENT':
+                case 'TOOLS_USING_AGENT':
+                    return 'AI_AGENT';
+                case 'LLM_GENERIC':
+                case 'RETRIEVAL_AUGMENTED_LLM':
+                    return 'GEN_AI_MODEL';
+                default:
+                    break;
+            }
+        }
+        return taggableType;
+    }
+
     this.fromNodeType = function(nodeType) {
         if (!nodeType) return;
 
@@ -577,8 +600,12 @@ app.filter('niceTaggableType', function($filter, $translate) {
         'SQL_NOTEBOOK': 'SQL notebook',
         'SEARCH_NOTEBOOK': 'Search notebook',
         'RETRIEVABLE_KNOWLEDGE': 'knowledge bank',
-        'TAGGABLE_OBJECT': 'item'
-    };
+        'TAGGABLE_OBJECT': 'item',
+        'INDEXABLE_OBJECT': 'item',
+        'GEN_AI_MODEL': 'GenAI model',
+        "AI_AGENT": 'AI agent'
+
+        };
     const plurals = {
         'ANALYSIS': 'analyses'
     };
@@ -1289,7 +1316,7 @@ app.controller('_TaggableObjectsMassActions', function($scope, $state, $rootScop
             selectablePlugins: []
         };
 
-        if ($scope.isAllEvaluationStores || $scope.isAllModels) {
+        if ($scope.isAllEvaluationStores?.() || $scope.isAllModels?.()) {
             usability.recipes.r.ok = false;
             usability.recipes.shell.ok = false;
             usability.recipes.julia.ok = false;
