@@ -909,6 +909,11 @@ app.directive('webAppInfra', function(DataikuAPI, $stateParams, $controller, Plu
             $scope.$watch("infra.containerSelection", function(nv, ov) {
                 if (!angular.equals(ov, nv)) fetchInfo()
             }, true);
+            $scope.canDisplayAdvancedSettings = function() {
+                let isK8s = $scope.containerInfo?.type === 'KUBERNETES';
+                let isDocker = $scope.containerInfo?.type === 'DOCKER';
+                return (isK8s || isDocker) && !$scope.isVirtualWebappSettings;
+            }
         }
     }
 });
