@@ -13,7 +13,7 @@ app.controller("CustomWebAppEditController", function($scope, $stateParams, Asse
     $scope.desc = $scope.loadedDesc.desc;
     $scope.isPythonBackendEnabled = function(app) {
         return (app.params.backendEnabled && $scope.getBaseType(app.type) === 'STANDARD')
-            || ['BOKEH', 'DASH'].includes($scope.getBaseType(app.type));
+            || ['BOKEH', 'DASH', 'STREAMLIT'].includes($scope.getBaseType(app.type));
     }
 
     if ($scope.app.apiKey) {
