@@ -26,9 +26,9 @@ from dataiku.base.utils import safe_unicode_str
 from dataiku.core import dkujson
 from dataiku.core import doctor_constants
 from dataiku.core import intercom
-from dataiku.core.dku_pandas_csv import dataframe_to_csv
 from dataiku.core.doctor_constants import TARGET_VARIABLE, TIME_VARIABLE
 from dataiku.core.percentage_progress import PercentageProgress
+from dataiku.core.saved_model import get_source_dss_version
 from dataiku.doctor import step_constants
 from dataiku.doctor import utils
 from dataiku.doctor.clustering.clustering_scorer import ClusteringModelScorer
@@ -57,9 +57,9 @@ from dataiku.doctor.prediction.common import regridify_optimized_params
 from dataiku.doctor.prediction.common import PredictionAlgorithmNaNSupport
 from dataiku.doctor.prediction.metric import MAPE
 from dataiku.doctor.timeseries.models import TimeseriesForecastingAlgorithm
+from dataiku.doctor.timeseries.posttraining.interactive_scenarios_handler import TimeseriesInteractiveScenariosHandler
 from dataiku.doctor.timeseries.preparation.preprocessing import TimeseriesPreprocessing, get_windows_list, \
-    add_rolling_windows
-from dataiku.doctor.timeseries.preparation.resampling.utils import get_frequency, get_monthly_day_alignment
+    add_rolling_windows_for_training, add_rolling_windows_for_scoring
 from dataiku.doctor.timeseries.score.scoring_handler import resample_for_scoring
 from dataiku.doctor.timeseries.train.training_handler import resample_for_training
 from dataiku.doctor.utils.gpu_execution import log_nvidia_smi_if_use_gpu
@@ -91,10 +91,8 @@ from dataiku.doctor.utils.split import load_test_set
 from dataiku.doctor.utils.split import load_train_set
 from dataikuscoring.utils.prediction_result import ClassificationPredictionResult
 from dataikuscoring.utils.prediction_result import PredictionResult
-from dataiku.doctor.timeseries.train.split_handler import TimeseriesInteractiveScoringSplitHandler
 from dataiku.doctor.timeseries.preparation.preprocessing import get_external_features
-from dataiku.doctor.timeseries.utils import timeseries_iterator, str_to_hash, ModelForecast, get_random_id, \
-    future_date_range
+from dataiku.doctor.timeseries.utils import ModelForecast
 from dataiku.doctor.timeseries.perf.model_perf import TimeseriesModelScorer
 from dataiku.doctor.timeseries.utils import get_dataframe_of_timeseries_identifier, SINGLE_TIMESERIES_IDENTIFIER
 
@@ -434,7 +432,7 @@ def compute_learning_curve(model_folder, preprocessing_folder, split_desc, split
     regridified_modeling_params = regridify_optimized_params(resolved_params, modeling_params)
     preprocessing_params = preprocessing_folder_context.read_json("rpreprocessing_params.json")  # within pp1/m1 ... what ?
     ml_overrides_params = ml_overrides_params_from_model_folder(model_folder_context)
-    nan_support = PredictionAlgorithmNaNSupport(modeling_params, preprocessing_params)
+    nan_support = PredictionAlgorithmNaNSupport(modeling_params, preprocessing_params, source_dss_version=get_source_dss_version(model_folder_context))
 
     split_params = split_desc["params"]
     n_folds = None
@@ -812,7 +810,7 @@ def create_ensemble(split_desc, core_params, model_folder, preprocessing_folder,
         prep_folder_context = preprocessing_folder_contexts[0]
         rppp = prep_folder_context.read_json("rpreprocessing_params.json")
         collector_data = prep_folder_context.read_json("collector_data.json")
-        nan_support = PredictionAlgorithmNaNSupport(ensemble_params["modeling_params"][0], rppp)
+        nan_support = PredictionAlgorithmNaNSupport(ensemble_params["modeling_params"][0], rppp, source_dss_version=get_source_dss_version(model_folder_contexts[0]))
         preprocessing_handler = PredictionPreprocessingHandler.build(core_params, rppp, prep_folder_context, nan_support=nan_support)
         preprocessing_handler.collector_data = collector_data
         pipe = preprocessing_handler.build_preprocessing_pipeline(with_target=True)
@@ -922,14 +920,14 @@ def compute_timeseries_residuals(job_id, split_desc, core_params, preprocessing_
     preprocessing_params = preprocessing_folder_context.read_json("rpreprocessing_params.json")
     listener = ProgressListener()
     modeling_params = model_folder_context.read_json("rmodeling_params.json")
-    full_timeseries_preprocessing = TimeseriesPreprocessing(preprocessing_folder_context, core_params, preprocessing_params, modeling_params, listener)
+    algorithm = TimeseriesForecastingAlgorithm.build(modeling_params["algorithm"])
+    full_timeseries_preprocessing = TimeseriesPreprocessing(preprocessing_folder_context, core_params, preprocessing_params, modeling_params, listener, algorithm.SUPPORTS_EXTERNAL_FEATURES)
     split_folder_context = build_folder_context(split_folder)
     full_df = load_train_set(core_params, preprocessing_params, split_desc, "full",
                    split_folder_context, use_diagnostics=False)
 
     resolved_params = model_folder_context.read_json("actual_params.json")["resolved"]
     optimized_modeling_params = regridify_optimized_params(resolved_params, modeling_params)
-    algorithm = TimeseriesForecastingAlgorithm.build(modeling_params["algorithm"])
     full_df = resample_for_training(
         full_df,
         split_desc["schema"],
@@ -942,7 +940,7 @@ def compute_timeseries_residuals(job_id, split_desc, core_params, preprocessing_
 
     # Windowing is performed once and for all on the full dataframe
     windows_list = get_windows_list(preprocessing_params) if modeling_params.get("isShiftWindowsCompatible", False) else []
-    full_df = add_rolling_windows(full_df, core_params, windows_list)
+    full_df = add_rolling_windows_for_training(full_df, core_params, windows_list, preprocessing_params, preprocessing_folder_context)
 
     transformed_full_df = full_timeseries_preprocessing.fit_and_process(
         full_df,
@@ -965,6 +963,12 @@ def compute_timeseries_interactive_scoring_creation(job_id, split_desc, core_par
                                  modellike_folder=None, computation_parameters=None, postcompute_folder=None,
                                  train_split_desc=None, train_split_folder=None):
 
+    computation_parameters = computation_parameters or {}
+    target_timeseries_identifier = computation_parameters.get('timeseriesIdentifier')
+    source_scenario_id = computation_parameters.get('scenarioId')
+    start_date_str = computation_parameters.get('startDate')
+    scenario_name = computation_parameters.get('scenarioName')
+
     model_folder_context = build_folder_context(model_folder)
     preprocessing_folder_context = build_folder_context(preprocessing_folder)
     preprocessing_params = preprocessing_folder_context.read_json("rpreprocessing_params.json")
@@ -973,6 +977,7 @@ def compute_timeseries_interactive_scoring_creation(job_id, split_desc, core_par
                              split_folder_context, use_diagnostics=False)
 
     modeling_params = model_folder_context.read_json("rmodeling_params.json")
+    resolved_params = model_folder_context.read_json("actual_params.json")["resolved"]
 
     external_features = get_external_features(preprocessing_params, modeling_params.get("isShiftWindowsCompatible", False))
     if len(external_features) == 0:
@@ -990,52 +995,12 @@ def compute_timeseries_interactive_scoring_creation(job_id, split_desc, core_par
 
     # We retrieve only identifiers that we trained on
     trained_models_identifiers = list(model_folder_context.read_json("forecasts.json.gz")["perTimeseries"].keys())
-
-
-    interactive_scoring_split_handler = TimeseriesInteractiveScoringSplitHandler(core_params)
-    _, scenario_df, _ = next(interactive_scoring_split_handler.split(full_df))
-
-    feature_columns = [core_params[doctor_constants.TIME_VARIABLE]] + core_params[doctor_constants.TIMESERIES_IDENTIFIER_COLUMNS] + external_features
-    scenario_df = scenario_df[feature_columns]
-
-    interactive_scoring_model_folder_context = model_folder_context.get_subfolder_context("interactive-scoring-analysis")
-    interactive_scoring_model_folder_context.create_if_not_exist()
-
-    identifier_columns = core_params[doctor_constants.TIMESERIES_IDENTIFIER_COLUMNS]
-    identifiers_mapping = {}
-
-    for idx, (timeseries_identifier, scenario_df_of_timeseries_identifier) in enumerate(timeseries_iterator(scenario_df, identifier_columns), 1):
-        if timeseries_identifier not in trained_models_identifiers:
-            continue
-        full_df_of_timeseries_identifier = get_dataframe_of_timeseries_identifier(full_df, timeseries_identifier)
-        csv_key = str_to_hash(timeseries_identifier)
-        identifiers_mapping[timeseries_identifier] = csv_key
-        timeseries_identifier_scenarios_folder_context = interactive_scoring_model_folder_context.get_subfolder_context(csv_key)
-        timeseries_identifier_scenarios_folder_context.create_if_not_exist()
-        new_scenario_id = get_random_id()
-        if not timeseries_identifier_scenarios_folder_context.isfile("scenarios_metadata.json"):
-            resolved_params = model_folder_context.read_json("actual_params.json")["resolved"]
-            algorithm = TimeseriesForecastingAlgorithm.build(modeling_params["algorithm"])
-            min_size_for_scoring = algorithm.get_min_size_for_scoring(resolved_params, preprocessing_params, core_params[doctor_constants.PREDICTION_LENGTH])
-            scenario_metadata = {
-                "names": {
-                    new_scenario_id: "historical"
-                },
-                "minStartDate": full_df_of_timeseries_identifier[core_params[TIME_VARIABLE]].iloc[min_size_for_scoring].strftime('%Y-%m-%dT%H:%M:%S.%f')[:-3],
-                "maxStartDate": future_date_range(full_df_of_timeseries_identifier[core_params[TIME_VARIABLE]].iloc[-1], 1, get_frequency(core_params), get_monthly_day_alignment(core_params))[0]
-            }
-            timeseries_identifier_scenarios_folder_context.write_json("scenarios_metadata.json", scenario_metadata)
-
-        # Remove identifier columns and keep only time, external features and scenario_id
-        columns_to_keep = [core_params[doctor_constants.TIME_VARIABLE]] + get_external_features(preprocessing_params)
-        scenario_df_without_identifiers = scenario_df_of_timeseries_identifier[columns_to_keep]
-
-        filename = "scenario-%s.csv" % new_scenario_id
-        with timeseries_identifier_scenarios_folder_context.get_file_path_to_write(filename) as predicted_file:
-            dataframe_to_csv(scenario_df_without_identifiers, predicted_file, open, header=True)
-
-    interactive_scoring_model_folder_context.write_json("identifiers_mapping.json", identifiers_mapping)
-
+    if target_timeseries_identifier in trained_models_identifiers:
+        interactive_scenarios_handler = TimeseriesInteractiveScenariosHandler(model_folder_context, resolved_params, preprocessing_params, core_params, full_df)
+        interactive_scenarios_handler.create_scenario(target_timeseries_identifier, source_scenario_id, pd.to_datetime(start_date_str), scenario_name)
+        interactive_scenarios_handler.dump_identifiers_mapping()
+    else:
+        logger.info("No model for timeseries identifier %s." % target_timeseries_identifier)
     return "ok"
 
 
@@ -1047,12 +1012,14 @@ def compute_timeseries_interactive_scoring_computation(job_id, split_desc, core_
     preprocessing_params = preprocessing_folder_context.read_json("rpreprocessing_params.json")
     split_folder_context = build_folder_context(split_folder)
     modeling_params = model_folder_context.read_json("rmodeling_params.json")
+    resolved_params = model_folder_context.read_json("actual_params.json")["resolved"]
+
     metrics_params = modeling_params["metrics"]
 
     listener = ProgressListener()
-    timeseries_preprocessing = TimeseriesPreprocessing(preprocessing_folder_context, core_params, preprocessing_params, modeling_params, listener)
-    clf = from_pkl(model_folder_context)
     algorithm = TimeseriesForecastingAlgorithm.build(modeling_params["algorithm"])
+    timeseries_preprocessing = TimeseriesPreprocessing(preprocessing_folder_context, core_params, preprocessing_params, modeling_params, listener, algorithm.SUPPORTS_EXTERNAL_FEATURES)
+    clf = from_pkl(model_folder_context)
     fit_before_predict = algorithm.should_fit_before_predict()
 
     interactive_scoring_model_folder_context = model_folder_context.get_subfolder_context("interactive-scoring-analysis")
@@ -1074,83 +1041,69 @@ def compute_timeseries_interactive_scoring_computation(job_id, split_desc, core_
 
     # Windowing is performed once and for all on the full dataframe
     windows_list = get_windows_list(preprocessing_params) if modeling_params.get("isShiftWindowsCompatible", False) else []
-    full_df = add_rolling_windows(full_df, core_params, windows_list)
+    full_df = add_rolling_windows_for_training(full_df, core_params, windows_list, preprocessing_params, preprocessing_folder_context)
 
-    external_features = get_external_features(preprocessing_params)
-    external_features_dtypes = {ef: full_df[ef].dtype for ef in external_features}
+    interactive_scenarios_handler = TimeseriesInteractiveScenariosHandler(model_folder_context, resolved_params, preprocessing_params, core_params, full_df)
 
-    timeseries_identifiers = computation_parameters['timeseriesIdentifiers']
+    identifier = computation_parameters['timeseriesIdentifier']
 
-    identifiers_mapping = interactive_scoring_model_folder_context.read_json("identifiers_mapping.json")
-    if interactive_scoring_model_folder_context.isfile("scenario-forecasts.json.gz"):
-        scenarios_results_by_identifiers = interactive_scoring_model_folder_context.read_json("scenario-forecasts.json.gz")
-    else:
-        scenarios_results_by_identifiers = {}
+    identifier_full_df = get_dataframe_of_timeseries_identifier(full_df, identifier)
+    preprocess_on_resampled_df = algorithm.USE_GLUON_TS
+    timeseries_preprocessing.load_resources()
+    timeseries_preprocessing.create_timeseries_preprocessing_handlers(identifier_full_df, preprocess_on_resampled_df, use_saved_resources=True)
 
-    for identifier in timeseries_identifiers:
-        scenarios_results_by_identifiers[identifier] = { "perScenarios": {} }
-        # Filter dataframe for current identifier
-        identifier_full_df = get_dataframe_of_timeseries_identifier(full_df, identifier)
+    transformed_full_df = timeseries_preprocessing.process(
+        identifier_full_df,
+        step_constants.ProcessingStep.STEP_PREPROCESS_TRAIN,
+        preprocess_on_resampled_df
+    )
 
-        identifier_hash = identifiers_mapping.get(identifier)
-        timeseries_identifier_scenarios_folder_context = interactive_scoring_model_folder_context.get_subfolder_context(identifier_hash)
-        scenarios_metadata = timeseries_identifier_scenarios_folder_context.read_json("scenarios_metadata.json")
-        preprocess_on_resampled_df = algorithm.USE_GLUON_TS
-        timeseries_preprocessing.load_resources()
-        timeseries_preprocessing.create_timeseries_preprocessing_handlers(identifier_full_df, preprocess_on_resampled_df, use_saved_resources=True)
+    date_format='%Y-%m-%dT%H:%M:%S.%fZ'
+    scenarios_metadata = interactive_scenarios_handler.get_scenarios_metadata(identifier)
+    for scenario_id, scenario_name in scenarios_metadata["names"].items():
+        scenario_df = interactive_scenarios_handler.get_scenario_df(identifier, scenario_id)
+        scenario_df[core_params[TARGET_VARIABLE]] = 0
+        scenario_df[core_params[TIME_VARIABLE]] = pd.to_datetime(scenario_df[core_params[TIME_VARIABLE]])
+        if identifier != SINGLE_TIMESERIES_IDENTIFIER:
+            for k, v in json.loads(identifier).items():
+                scenario_df[k] = v
+        for external_feature in external_features:
+            if external_feature not in scenario_df.columns:
+                scenario_df[external_feature] = pd.Series(None, index=scenario_df.index, dtype=full_df[external_feature].dtype)
 
-        transformed_full_df = timeseries_preprocessing.process(
-            identifier_full_df,
-            step_constants.ProcessingStep.STEP_PREPROCESS_TRAIN,
+        # Process each scenario separately
+        historical_df_subset = transformed_full_df[pd.to_datetime(identifier_full_df[core_params[doctor_constants.TIME_VARIABLE]]) < np.datetime64(scenario_df[core_params[doctor_constants.TIME_VARIABLE]].iloc[0])]
+
+        # Process the updated_test_df for the current scenario
+        scenario_df = add_rolling_windows_for_scoring(scenario_df, core_params, windows_list, preprocessing_params, preprocessing_folder_context)
+        transformed_scenario_df = timeseries_preprocessing.process(
+            scenario_df,
+            step_constants.ProcessingStep.STEP_PREPROCESS_TEST,
             preprocess_on_resampled_df
         )
-        # Process each scenario separately
-        for scenario_id in scenarios_metadata["names"].keys():
-            with timeseries_identifier_scenarios_folder_context.get_file_path_to_read("scenario-%s.csv" % scenario_id) as scenario_path:
-                scenario_df = pd.read_csv(scenario_path, sep="\t", dtype=external_features_dtypes)
 
-            # Same as for the scoring recipe, avoid preprocessing failing with only NaN in target column, and future target values won't be used anyway to predict
-            # see TimeseriesScoringHandler::_split_past_and_future_df
-            scenario_df[core_params[TARGET_VARIABLE]] = 0
-            scenario_df[core_params[TIME_VARIABLE]] = pd.to_datetime(scenario_df[core_params[TIME_VARIABLE]])
-            if identifier != SINGLE_TIMESERIES_IDENTIFIER:
-                # Populate identifiers column if required
-                for k, v in json.loads(identifier).items():
-                    scenario_df[k] = v
+        model_scorer = TimeseriesModelScorer.build(core_params, metrics_params, use_external_features=True)
+        timeseries_forecasts = model_scorer.predict_all_test_timesteps(clf, historical_df_subset, transformed_scenario_df, fit_before_predict)[identifier]
+        forecasts = {
+            "forecast": timeseries_forecasts[ModelForecast.FORECAST_VALUES],
+            "forecastTime": timeseries_forecasts[ModelForecast.TIMESTAMPS],
+            "quantiles": []
+        }
+        for idx, q in enumerate(model_scorer.quantiles):
+            forecasts["quantiles"].append({
+                "forecast": timeseries_forecasts[ModelForecast.QUANTILES_FORECASTS][idx],
+                "quantile": q
+            })
+        serializable_forecasts = model_scorer.remove_nanif_in_one_forecast(forecasts)
+        scenarios_forecasts = {
+            "forecastTime": transformed_scenario_df[core_params[doctor_constants.TIME_VARIABLE]].astype(str).values,
+            "groundTruthTime": historical_df_subset[core_params[doctor_constants.TIME_VARIABLE]][-max(2, len(scenario_df)):].dt.strftime(date_format).values,
+            "groundTruth": historical_df_subset[core_params[doctor_constants.TARGET_VARIABLE]][-max(2, len(scenario_df)):].values,
+        }
+        scenarios_forecasts["forecast"] = serializable_forecasts["forecast"]
+        scenarios_forecasts["quantiles"] = serializable_forecasts["quantiles"]
+        interactive_scenarios_handler.write_scenarios(scenarios_forecasts, identifier, scenario_id)
 
-            historical_df_subset = transformed_full_df[pd.to_datetime(identifier_full_df[core_params[doctor_constants.TIME_VARIABLE]]) < np.datetime64(scenario_df[core_params[doctor_constants.TIME_VARIABLE]].iloc[0])]
-            scenarios_forecasts = {
-                "forecastTime": scenario_df[core_params[doctor_constants.TIME_VARIABLE]].astype(str).values,
-                "groundTruthTime": historical_df_subset[core_params[doctor_constants.TIME_VARIABLE]][-max(2, len(scenario_df)):].astype(str).values,
-                "groundTruth": historical_df_subset[core_params[doctor_constants.TARGET_VARIABLE]][-max(2, len(scenario_df)):].values,
-            }
-
-            # Process the updated_test_df for the current scenario
-            transformed_scenario_df = timeseries_preprocessing.process(
-                scenario_df,
-                step_constants.ProcessingStep.STEP_PREPROCESS_TEST,
-                preprocess_on_resampled_df
-            )
-
-            model_scorer = TimeseriesModelScorer.build(core_params, metrics_params, use_external_features=True)
-            timeseries_forecasts = model_scorer.predict_all_test_timesteps(clf, historical_df_subset, transformed_scenario_df, fit_before_predict)[identifier]
-            forecasts = {
-                "forecast": timeseries_forecasts[ModelForecast.FORECAST_VALUES],
-                "forecastTime": timeseries_forecasts[ModelForecast.TIMESTAMPS],
-                "quantiles": []
-            }
-            for idx, q in enumerate(model_scorer.quantiles):
-                forecasts["quantiles"].append({
-                    "forecast": timeseries_forecasts[ModelForecast.QUANTILES_FORECASTS][idx],
-                    "quantile": q
-                })
-            serializable_forecasts = model_scorer.remove_nanif_in_one_forecast(forecasts)
-
-            scenarios_forecasts["forecast"] = serializable_forecasts["forecast"]
-            scenarios_forecasts["quantiles"] = serializable_forecasts["quantiles"]
-            scenarios_results_by_identifiers[identifier]["perScenarios"][scenarios_metadata["names"][scenario_id]] = scenarios_forecasts
-
-    interactive_scoring_model_folder_context.write_json("scenario-forecasts.json.gz", scenarios_results_by_identifiers)
     return "ok"
 
 
