@@ -450,8 +450,9 @@ class PredictionModelInformationHandler(PredictionModelInformationHandlerBase):
 
     def get_preproc_handler(self):
         if self._preproc_handler is None:
+            from dataiku.core.saved_model import get_source_dss_version
             from dataiku.doctor.prediction.common import PredictionAlgorithmNaNSupport
-            nan_support = PredictionAlgorithmNaNSupport(self._modeling_params, self._preprocessing_params)
+            nan_support = PredictionAlgorithmNaNSupport(self._modeling_params, self._preprocessing_params, source_dss_version=get_source_dss_version(self._model_folder_context))
             self._preproc_handler = PredictionPreprocessingHandler.build(self._core_params, self._preprocessing_params,
                                                                          self._preprocessing_folder_context, nan_support=nan_support)
             self._preproc_handler.collector_data = self.get_collector_data()
