@@ -1133,10 +1133,11 @@ class PredictionAlgorithmNaNSupport(object):
         'XGBOOST_CLASSIFICATION', 'XGBOOST_REGRESSION'
     }
 
-    def __init__(self, modeling_params, preprocessing_params=None):
+    def __init__(self, modeling_params, preprocessing_params=None, source_dss_version=None):
         self.modeling_params = modeling_params
         self.algorithm = self.modeling_params["algorithm"]
         self.preprocessing_params = preprocessing_params
+        self._source_dss_version = source_dss_version
         feature_reduction = preprocessing_params["feature_selection_params"]["method"] if preprocessing_params is not None else None
         self.supports_nan = self._supports_nan(feature_reduction)
 
@@ -1173,12 +1174,20 @@ class PredictionAlgorithmNaNSupport(object):
         #   - treating unrecorded as NaN (XGBoost)
         # The purpose of this property is to provide consistency between sparse and dense representation of
         # the data, for all ML algorithms being used to train the model
+        #
+        # Backward compatibility: before DSS 13.4.0, unrecorded_value always returned 0, even for XGBoost.
+        # Models trained before 13.4.0 must continue to use 0 for consistent scoring results.
+        if self._source_dss_version is not None and self._source_dss_version < 13400:
+            return 0.
         if self.supports_nan and self.algorithm in self.ALGORITHMS_WITH_UNRECORDED_AS_NAN:
             return np.nan
         else:
             return 0.
 
 
+
+
+
 class DefaultPredictionAlgorithmNaNSupport(object):
 
     @property
