@@ -243,16 +243,31 @@ def get_shift_map(preprocessing_params, generated_features_mappings):
 
 
 def get_windows_list(preprocessing_params):
-    windows_list = copy.deepcopy(preprocessing_params["feature_generation"]["windows"])
-    for window in windows_list:
-        operations_map = window["operations_map"]
-        for feature, operations in operations_map.items():
-            operations_map[feature] = [op["operation"] for op in operations if op["enabled"] and is_window_compatible(preprocessing_params["per_feature"][feature], op["operation"])]
+    """
+    :param preprocessing_params: the one and only
+    :return: list of dict, each dict represents a clean non-empty window configuration where columns with empty operations
+             lists (incompatible `role`, or incompatible `type` for enabled operations) are filtered out
+    """
+    windows_list = []
+    for window in preprocessing_params["feature_generation"]["windows"]:
+        filtered_operations_map = {}
+        for feature, operations in window["operations_map"].items():
+            valid_operations = [op["operation"] for op in operations if op["enabled"] and is_window_compatible(preprocessing_params["per_feature"][feature], op["operation"])]
+            if len(valid_operations) > 0:
+                filtered_operations_map[feature] = valid_operations
+        if len(filtered_operations_map) > 0:
+            filtered_window = {
+                "operations_map": filtered_operations_map,
+                "length": window["length"],
+                "shift": window["shift"],
+                "is_from_forecast": window["is_from_forecast"],
+            }
+            windows_list.append(filtered_window)
     return windows_list
 
 
 class TimeseriesPreprocessing:
-    def __init__(self, data_folder_context, core_params, preprocessing_params, modeling_params, listener, windows_resources_folder_context=None):
+    def __init__(self, data_folder_context, core_params, preprocessing_params, modeling_params, listener, support_external_features, windows_resources_folder_context=None):
         self.data_folder_context = data_folder_context
         if windows_resources_folder_context is not None:
             self.windows_resources_folder_context = windows_resources_folder_context
@@ -262,6 +277,7 @@ class TimeseriesPreprocessing:
         self.preprocessing_params = preprocessing_params
         self.modeling_params = modeling_params
         self.listener = listener
+        self.support_external_features = support_external_features
 
         self.preproc_handler_by_timeseries = {}
         self.pipeline_by_timeseries = {}
@@ -270,7 +286,7 @@ class TimeseriesPreprocessing:
         self.external_features = {}
 
     def create_timeseries_preprocessing_handlers(self, df, on_full_df, use_saved_resources=False):
-        if not has_external_features_or_windows(self.preprocessing_params, self.modeling_params.get("isShiftWindowsCompatible", False)):
+        if not self.support_external_features or not has_external_features_or_windows(self.preprocessing_params, self.modeling_params.get("isShiftWindowsCompatible", False)):
             return
 
         with self.listener.push_step(step_constants.ProcessingStep.STEP_COLLECTING):
@@ -293,7 +309,7 @@ class TimeseriesPreprocessing:
                     )
 
     def fit_and_process(self, df, step_name, on_full_df, save_data=False):
-        if not has_external_features_or_windows(self.preprocessing_params, self.modeling_params.get("isShiftWindowsCompatible", False)):
+        if not self.support_external_features or not has_external_features_or_windows(self.preprocessing_params, self.modeling_params.get("isShiftWindowsCompatible", False)):
             if save_data:
                 self._save_data()
                 self._report()
@@ -322,7 +338,7 @@ class TimeseriesPreprocessing:
         return transformed_df
 
     def process(self, df, step_name, on_full_df):
-        if not has_external_features_or_windows(self.preprocessing_params, self.modeling_params.get("isShiftWindowsCompatible", False)):
+        if not self.support_external_features or not has_external_features_or_windows(self.preprocessing_params, self.modeling_params.get("isShiftWindowsCompatible", False)):
             return df
 
         timeseries_identifier_columns = self.core_params[TIMESERIES_IDENTIFIER_COLUMNS]
@@ -550,10 +566,10 @@ def add_rolling_windows(full_df, core_params, windows_list, preprocessing_params
             length = window["length"]
             operations_map = window["operations_map"]
             for column_name in operations_map.keys():
-                if column_name not in full_df.columns:
-                    raise ValueError("The input does not include the required column '{}'".format(column_name))
                 if len(operations_map[column_name]) == 0:
                     continue
+                elif column_name not in full_df.columns:
+                    raise ValueError("The input does not include the required column '{}'".format(column_name))
                 single_col_series = df_of_timeseries_identifier[column_name].copy()
                 feature_type = preprocessing_params["per_feature"][column_name]["type"]
                 if feature_type == "CATEGORY" and preprocessing_params["per_feature"][column_name][CATEGORY_HANDLING] == DUMMIFY:
