@@ -1,5 +1,5 @@
 import os, json, shutil
-from dataiku.code_studio import CodeStudioBlock, get_dataiku_user_uid
+from dataiku.code_studio import CodeStudioBlock, get_dataiku_user_uid_gid
 
 from block_utils import LibLocationPathReplacer, build_generate_python_codenv_script
 
@@ -63,11 +63,11 @@ COPY aicodeassistant.vsix /opt/dataiku/
 RUN chown dataiku:dataiku /opt/dataiku/aicodeassistant.vsix && chmod +x /opt/dataiku/aicodeassistant.vsix
 
 # USER dataiku
-USER {uid}
+USER {uid_gid}
 WORKDIR /home/dataiku
 
 RUN code-server --extensions-dir /home/dataiku/.local/share/code-server/local-extensions --install-extension /opt/dataiku/aicodeassistant.vsix
-""".format(uid=get_dataiku_user_uid())
+""".format(uid_gid=get_dataiku_user_uid_gid())
 
         extensions = []
         if python_ext_version is not None and python_ext_version != 'none':
@@ -224,7 +224,7 @@ openfile() {
     countExec=1
     until [ $countExec -gt 15 ]
         do
-            code-server -r "$1/$2" 2>&1 | grep error
+            code-server --user-data-dir ##SETTINGS_PATH## -r "$1/$2" 2>&1 | grep error
             if [ $? != 0 ]
                 then
                     echo "Request n°$countExec to open file $1/$2 in VSCode succeeded!"
@@ -237,6 +237,7 @@ openfile() {
 }
 openfile "$1" "$2"
 """
+        openfile_script = openfile_script.replace("##SETTINGS_PATH##", settings_path)
         with open(os.path.join(env["buildDir"], "vscode-openfile.sh"), "wb") as f:
             f.write(openfile_script.encode("utf8"))
 
@@ -276,7 +277,7 @@ RUN find /home/dataiku/ -name .cache | while read line; do chown -R dataiku: $li
 RUN find /home/dataiku/ -name .ipython | while read line; do chown -R dataiku: $line; done
 
 #USER dataiku
-USER {uid} 
+USER {uid_gid}
 WORKDIR /home/dataiku
 
 # install to temporary folder, will be linked to user's dir on first launch, see vscode-entrypoint.sh
@@ -290,7 +291,7 @@ WORKDIR /home/dataiku
            py_dss_pyenv_path=py_dss_pyenv_path,
            py_dss_env_name=py_dss_env_name,
            py_dss_env_label=py_dss_env_label,
-           uid=get_dataiku_user_uid())
+           uid_gid=get_dataiku_user_uid_gid())
         return spec
 
     def build_launch(self, spec, env):
